@@ -2,6 +2,7 @@ mod client;
 mod connection;
 mod errors;
 mod query;
+mod resource;
 mod stream;
 #[cfg(test)]
 mod tests;
@@ -9,7 +10,7 @@ mod tests;
 pub use client::Client;
 pub use connection::Connection;
 pub use errors::ClientError;
-pub use query::{Query, ToQueryArgument, ArgumentWriter};
+pub use query::{compiler, serializer, ArgumentWriter, Query, ToQueryArgument, WithInfo, WithoutInfo};
 pub use stream::DatabaseStream;
 
 /// A [`Result`] with its [`Err`] variant set to [`ClientError`].
