@@ -1,10 +1,16 @@
+pub mod compiler;
+pub mod serializer;
+
+mod argument;
+mod errors;
+#[allow(clippy::module_inception)]
 mod query;
 mod response;
-mod errors;
-mod argument;
 
-pub use self::query::Query;
-pub use self::errors::QueryFailed;
-pub use self::response::Response;
-pub use self::argument::ToQueryArgument;
 pub use self::argument::ArgumentWriter;
+pub use self::argument::ToQueryArgument;
+pub use self::errors::QueryFailed;
+pub use self::query::Query;
+pub use self::query::WithInfo;
+pub use self::query::WithoutInfo;
+pub use self::response::Response;
