@@ -1,6 +1,6 @@
-use std::io::{Write, Read};
-use std::net::TcpStream;
 use crate::Result;
+use std::io::{Read, Write};
+use std::net::TcpStream;
 
 /// Represents a stream usable for BaseX database [`Connection`].
 ///
@@ -13,11 +13,11 @@ pub trait DatabaseStream: Read + Write + Sized {
     ///
     /// The returned instance is a reference to the same stream that this object references. Both handles will read and
     /// write the same stream of data, and options set on one stream will be propagated to the other stream.
-    fn try_clone(&mut self) -> Result<Self>;
+    fn try_clone(&self) -> Result<Self>;
 }
 
 impl DatabaseStream for TcpStream {
-    fn try_clone(&mut self) -> Result<Self> {
+    fn try_clone(&self) -> Result<Self> {
         Ok(TcpStream::try_clone(self)?)
     }
 }
