@@ -7,12 +7,12 @@ use basex::{Client, ClientError};
 fn test_query_recognizes_updating_statements() -> Result<(), ClientError> {
     let client = Client::connect("localhost", 1984, "admin", "admin")?;
 
-    let mut non_updating_query = client.query(&mut "count(/None/*)".as_bytes())?;
+    let mut non_updating_query = client.query("count(/None/*)")?.without_info()?;
     assert!(!non_updating_query.updating()?);
 
     let client = non_updating_query.close()?;
 
-    let mut updating_query = client.query(&mut "replace value of node /None with 1".as_bytes())?;
+    let mut updating_query = client.query("replace value of node /None with 1")?.without_info()?;
     assert!(updating_query.updating()?);
 
     updating_query.close()?;
